@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2010 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2023 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,29 +12,28 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #ifndef KMETROPREFERENCES_H
 #define KMETROPREFERENCES_H
 
+#include <QDialog>
 #include "ui_kmetropreferencesbase.h"
 #include "instrument.h"
-#include <KDE/KDialog>
 
-class KMetroPreferences : public KDialog
+class KMetroPreferences : public QDialog
 {
     Q_OBJECT
 
 public:
-    KMetroPreferences(QWidget *parent = 0);
+    KMetroPreferences(QWidget *parent = nullptr);
     virtual ~KMetroPreferences();
     void fillInputConnections(QStringList lst) { m_ui.m_in_connection->insertItems(0, lst); }
     void fillOutputConnections(QStringList lst) { m_ui.m_out_connection->insertItems(0, lst); }
     void fillInstruments(InstrumentList* instruments);
+    void fillStyles();
     bool getAutoConnect() { return m_ui.m_autoconn->isChecked(); }
     QString getOutputConnection() { return m_ui.m_out_connection->currentText(); }
     QString getInputConnection() { return m_ui.m_in_connection->currentText(); }
@@ -42,12 +41,14 @@ public:
     int getResolution() { return m_ui.m_resolution->value(); }
     int getDuration() { return m_ui.m_duration->value(); }
     bool getSendNoteOff() { return m_ui.m_use_noteoff->isChecked(); }
-    bool getStyledKnobs() { return m_ui.m_styledknobs->isChecked(); }
     QString getInstrumentName();
-    QString  getProgramName();
-    QString  getBankName();
+    QString getProgramName();
+    QString getBankName();
+    QString getStyle();
     int getWeakNote();
     int getStrongNote();
+    bool getDarkMode() { return m_ui.m_dark_mode->isChecked(); }
+    bool getInternalIcons() { return m_ui.m_internal_icons->isChecked(); }
 
     void setAutoConnect(bool newValue) { m_ui.m_autoconn->setChecked(newValue); }
     void setOutputConnection(QString newValue);
@@ -56,12 +57,13 @@ public:
     void setResolution(int newValue) { m_ui.m_resolution->setValue(newValue); }
     void setDuration(int newValue) { m_ui.m_duration->setValue(newValue); }
     void setSendNoteOff(bool newValue) { m_ui.m_use_noteoff->setChecked(newValue); }
-    void setStyledKnobs(bool newValue) { m_ui.m_styledknobs->setChecked(newValue); }
     void setWeakNote(int newValue);
     void setStrongNote(int newValue);
     void setInstrumentName(QString name);
     void setProgramName(QString name);
     void setBankName(QString name);
+    void setDarkMode(bool mode) { m_ui.m_dark_mode->setChecked(mode); }
+    void setInternalIcons(bool icons) { m_ui.m_internal_icons->setChecked(icons); }
 
 public slots:
     void slotInstrumentChanged(int idx);
